Options
=======

Command line options
--------------------

These command line options are supported by the release commands
(``saruman workers enable``, ``saruman workers enable``, ``saruman workers enable``, ``saruman firewall start``).

-v, --verbose
    Run in verbose mode, printing a bit more, mostly only interesting
    for debugging.

-h, --help
    Display help text

